@@ -245,8 +245,8 @@ class FrogMLClient:
     def list_builds(
         self,
         model_id: str,
-        tags: List[str],
-        filters: List[Union[MetricFilter, ParameterFilter]],
+        tags: Optional[List[str]] = None,
+        filters: Optional[List[Union[MetricFilter, ParameterFilter]]] = None,
     ) -> List[Build]:
         """
         List builds by its model ID and explicit filters
@@ -260,6 +260,9 @@ class FrogMLClient:
              List[Build]: List of builds that contains the requested filters.
 
         """
+        tags = tags if tags is not None else []
+        filters = filters if filters is not None else []
+
         model = self._get_model_management().get_model(model_id=model_id)
         model_uuid = model.uuid
 
